.. katapayadi documentation master file, created by
   sphinx-quickstart on Mon Sep 16 23:40:42 2013.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

katapayadi
==========

Katapayadi Sankhya
------------------

`Katapayadi sankhya <http://en.wikipedia.org/wiki/Katapayadi_sankhya>`_ is
a simplification of `Aryabhata <http://en.wikipedia.org/wiki/Aryabhata>`_
's `Sanskrit numerals <http://en.wikipedia.org/wiki/Sanskrit_numerals>`_ ,
due probably to `Haridatta <http://www.google.com/search?hl=en&q=Haridatta&btnG=Google+Search>`_ from
Kerala.  In Malayalam it is also known as 'Paralperu' For eg:
ചണ്ഡാംശുചന്ദ്രാധമകുംഭിപാല represents 31415926536 which is
π*1000000000000000 More examples in Malayalam are given in this `page <http://ml.wikipedia.org/wiki/Paralperu>`_

Swarasthana of Melakartha Raga
------------------------------

The Katapayadi sankhya is a way of determining the number of a
Melakarta raga from the first two syllables of the name of the Raga.

The algorithm used in this is explained in detail here:
 `An Algorithm to derive the Swarasthanas <http://en.wikipedia.org/wiki/Katapayadi_sankhya#An_Algorithm_to_derive_the_Swarasthanas>`_

Usage
--------

 >>> from katapayadi import getInstance
 >>> k = getInstance()
 >>> k.get_number(u"കമല")
 351
 >>> k.get_swarasthanas(1)
 ['Sa', 'Ri1', 'Ga1', 'Ma1', 'Pa', 'Da1', 'Ni1', 'Sa']

API referece
------------

.. automodule:: katapayadi.core
   :members:

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
